@@ -8,6 +8,8 @@ from os import walk, sep, fsdecode
 
 from IPython.core.display import DisplayObject, TextDisplayObject
 
+from typing import Tuple, Iterable
+
 __all__ = ['Audio', 'IFrame', 'YouTubeVideo', 'VimeoVideo', 'ScribdDocument',
            'FileLink', 'FileLinks', 'Code']
 
@@ -130,7 +132,6 @@ class Audio(DisplayObject):
     @staticmethod
     def _make_wav(data, rate, normalize):
         """ Transform a numpy array to a PCM bytestring """
-        import struct
         from io import BytesIO
         import wave
 
@@ -145,14 +146,14 @@ class Audio(DisplayObject):
         waveobj.setframerate(rate)
         waveobj.setsampwidth(2)
         waveobj.setcomptype('NONE','NONE')
-        waveobj.writeframes(b''.join([struct.pack('<h',x) for x in scaled]))
+        waveobj.writeframes(scaled)
         val = fp.getvalue()
         waveobj.close()
 
         return val
 
     @staticmethod
-    def _validate_and_normalize_with_numpy(data, normalize):
+    def _validate_and_normalize_with_numpy(data, normalize) -> Tuple[bytes, int]:
         import numpy as np
 
         data = np.array(data, dtype=float)
@@ -170,12 +171,16 @@ class Audio(DisplayObject):
         
         max_abs_value = np.max(np.abs(data))
         normalization_factor = Audio._get_normalization_factor(max_abs_value, normalize)
-        scaled = np.int16(data / normalization_factor * 32767).tolist()
-        return scaled, nchan
-
+        scaled = data / normalization_factor * 32767
+        return scaled.astype("<h").tobytes(), nchan
 
     @staticmethod
     def _validate_and_normalize_without_numpy(data, normalize):
+        import array
+        import sys
+
+        data = array.array('f', data)
+
         try:
             max_abs_value = float(max([abs(x) for x in data]))
         except TypeError:
@@ -183,9 +188,11 @@ class Audio(DisplayObject):
                 'supported if numpy is not installed')
 
         normalization_factor = Audio._get_normalization_factor(max_abs_value, normalize)
-        scaled = [int(x / normalization_factor * 32767) for x in data]
+        scaled = array.array('h', [int(x / normalization_factor * 32767) for x in data])
+        if sys.byteorder == 'big':
+            scaled.byteswap()
         nchan = 1
-        return scaled, nchan
+        return scaled.tobytes(), nchan
 
     @staticmethod
     def _get_normalization_factor(max_abs_value, normalize):
@@ -248,13 +255,18 @@ class IFrame(object):
             src="{src}{params}"
             frameborder="0"
             allowfullscreen
+            {extras}
         ></iframe>
         """
 
-    def __init__(self, src, width, height, **kwargs):
+    def __init__(self, src, width, height, extras: Iterable[str] = None, **kwargs):
+        if extras is None:
+            extras = []
+
         self.src = src
         self.width = width
         self.height = height
+        self.extras = extras
         self.params = kwargs
 
     def _repr_html_(self):
@@ -267,10 +279,14 @@ class IFrame(object):
             params = "?" + urlencode(self.params)
         else:
             params = ""
-        return self.iframe.format(src=self.src,
-                                  width=self.width,
-                                  height=self.height,
-                                  params=params)
+        return self.iframe.format(
+            src=self.src,
+            width=self.width,
+            height=self.height,
+            params=params,
+            extras=" ".join(self.extras),
+        )
+
 
 class YouTubeVideo(IFrame):
     """Class for embedding a YouTube Video in an IPython session, based on its video id.
@@ -298,11 +314,14 @@ class YouTubeVideo(IFrame):
     will be inserted in the document.
     """
 
-    def __init__(self, id, width=400, height=300, **kwargs):
+    def __init__(self, id, width=400, height=300, allow_autoplay=False, **kwargs):
         self.id=id
         src = "https://www.youtube.com/embed/{0}".format(id)
+        if allow_autoplay:
+            extras = list(kwargs.get("extras", [])) + ['allow="autoplay"']
+            kwargs.update(autoplay=1, extras=extras)
         super(YouTubeVideo, self).__init__(src, width, height, **kwargs)
-    
+
     def _repr_jpeg_(self):
         # Deferred import
         from urllib.request import urlopen
